Page MenuHomeFreeBSD

D19835.1775553519.diff
No OneTemporary

Size
574 B
Referenced Files
None
Subscribers
None

D19835.1775553519.diff

Index: sys/vm/uma_core.c
===================================================================
--- sys/vm/uma_core.c
+++ sys/vm/uma_core.c
@@ -1916,10 +1916,11 @@
*/
zone_drain_wait(zone, M_WAITOK);
/*
* We only destroy kegs from non secondary zones.
*/
- if ((keg = zone->uz_keg) != NULL &&
+ if ((zone->uz_flags & UMA_ZFLAG_CACHE) == 0 &&
(zone->uz_flags & UMA_ZONE_SECONDARY) == 0) {
+ keg = zone->uz_keg;
rw_wlock(&uma_rwlock);
LIST_REMOVE(keg, uk_link);
rw_wunlock(&uma_rwlock);
@@ -1916,10 +1916,11 @@
zone_drain_wait(zone, M_WAITOK);
/*
- * We only destroy kegs from non secondary zones.
+ * We only destroy kegs from non secondary/non cache zones.
*/

File Metadata

Mime Type
text/plain
Expires
Tue, Apr 7, 9:18 AM (2 h, 27 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
28291542
Default Alt Text
D19835.1775553519.diff (574 B)

Event Timeline